pub struct WireCorrelation {
pub kind: i32,
pub wire_req_id: u64,
}Expand description
Correlation header. Empty wire_req_id (= 0) is valid only when
kind == NONE.
Fields
kind: i32wire_req_id: u64Implementations
Sourceimpl WireCorrelation
impl WireCorrelation
Sourcepub fn kind(&self) -> CorrelationKind
pub fn kind(&self) -> CorrelationKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: CorrelationKind)
pub fn set_kind(&mut self, value: CorrelationKind)
Sets kind to the provided enum value.