pub struct NodeProto {
pub input: Vec<String>,
pub output: Vec<String>,
pub name: String,
pub op_type: String,
pub domain: String,
pub overload: String,
pub attribute: Vec<AttributeProto>,
pub doc_string: String,
pub metadata_props: Vec<StringStringEntryProto>,
pub device_configurations: Vec<NodeDeviceConfigurationProto>,
}Expand description
Nodes
Computation graphs are made up of a DAG of nodes, which represent what is commonly called a “layer” or “pipeline stage” in machine learning frameworks.
For example, it can be a node of type “Conv” that takes in an image, a filter tensor and a bias tensor, and produces the convolved output.
Fields
input: Vec<String>namespace Value
output: Vec<String>namespace Value
name: StringAn optional identifier for this node in a graph. This field MAY be absent in this version of the IR.
namespace Node
op_type: StringThe symbolic identifier of the Operator to execute.
namespace Operator
domain: StringThe domain of the OperatorSet that specifies the operator named by op_type.
namespace Domain
overload: StringOverload identifier, used only to map this to a model-local function.
attribute: Vec<AttributeProto>Additional named attributes.
doc_string: StringA human-readable documentation for this node. Markdown is allowed.
metadata_props: Vec<StringStringEntryProto>Named metadata values; keys should be distinct.
device_configurations: Vec<NodeDeviceConfigurationProto>Configuration of multi-device annotations.