pub struct ShardedDimProto {
pub axis: i64,
pub simple_sharding: Vec<SimpleShardedDimProto>,
}Expand description
ShardedDimProto: This describes the sharding spec for a single axis of a sharded tensor.
Fields
axis: i64This field MUST be present for this version of the IR. The axis this sharding corresponds to. Must be in the range of [-r, r - 1], where r is the rank of the tensor. Negative axis values means counting from the back.
simple_sharding: Vec<SimpleShardedDimProto>Describes how the tensor on the provided axis is sharded. The common-case is described by a single instance of SimpleShardedDimProto. Multiple instances can be used to handle cases where a sharded tensor is reshaped, fusing multiple axes into one.