pub struct ShardingSpecProto {
pub tensor_name: String,
pub device: Vec<i64>,
pub index_to_device_group_map: Vec<IntIntListEntryProto>,
pub sharded_dim: Vec<ShardedDimProto>,
}Expand description
ShardingSpecProto: This describes the sharding spec for a specific input or output tensor of a node.
Fields
tensor_name: StringThis field MUST be present for this version of the IR.
Identifies the input or output of the node that is being sharded.
Required to match a name specified in the node’s input or output list of ValueInfoProtos.
It is called logical tensor in subsequent descriptions.
device: Vec<i64>The following is the list of devices across which the logical tensor is sharded or replicated.
index_to_device_group_map: Vec<IntIntListEntryProto>Each element v in above field devices may represent either a device or a set of devices (when we want the same shard/tensor to be replicated across a subset of devices), as indicated by the following optional map. If the map contains an entry for v, then v represents a device group, and the map indicates the set of devices in that group.
sharded_dim: Vec<ShardedDimProto>The following is the sharded-shape of the tensor, consisting of the sharding-spec for each axis of the tensor.