pub struct SimpleShardedDimProto {
pub num_shards: i64,
pub dim: Option<Dim>,
}Expand description
SimpleShardedDimProto: Indicates that N blocks are divided into M shards. N is allowed to be symbolic where M is required to be a constant.
Fields
num_shards: i64This field MUST be present for this version of the IR. Number of shards to split dim into.
dim: Option<Dim>Dimension value to be sharded.