#[repr(i32)]pub enum DataLocation {
Default = 0,
External = 1,
}Expand description
Location of the data for this tensor. MUST be one of:
- DEFAULT - data stored inside the protobuf message. Data is stored in raw_data (if set) otherwise in type-specified field.
- EXTERNAL - data stored in an external location as described by external_data field.
Variants
Implementations
Sourceimpl DataLocation
impl DataLocation
Sourceimpl DataLocation
impl DataLocation
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<DataLocation>
pub fn from_str_name(value: &str) -> Option<DataLocation>
Creates an enum from field names used in the ProtoBuf definition.